/* 
 * File:   playmuteregion.cpp
 *
 * Finale PDK Framework sample plug-in.
 *
 */


#include "finaleframework.h"


class FCEntryPlaybackIH : public FCIteratorHandler
{
    bool playback;
public:
    FCEntryPlaybackIH(bool shouldplayback) : FCIteratorHandler()
        { playback = shouldplayback; }
    virtual bool Iterate(__FCBase* object);
};

bool FCEntryPlaybackIH::Iterate(__FCBase* object)
{
    FCNoteEntry* pEntry = (FCNoteEntry*) object;
    if (pEntry->IsNote()) pEntry->SetPlayback(playback);
    return true;
}

void MuteOrUnmuteNotes(FCMusicRegion* pRegion, bool playback)
{
    FCBrowserNoteEntries browser;
    FCEntryPlaybackIH myIteratorHandler(playback);
    myIteratorHandler.SetSaveAfterIterate(true);
    browser.ForEachInRegion(&myIteratorHandler, pRegion);
}

// **********************************
// Required Finale callback functions
// **********************************

EVERSION FINEXPORT FinaleExtensionVersion(const EVERSION hiVersion) {
    SetFinaleFrameworkVersion(hiVersion);
    return hiVersion;
}

tbool FINEXPORT FinaleExtensionInit(
        const EWND hWnd,
        FLAG_32 *flags
) {
    *flags |= EXTATTRIB_LINKED_PARTS_AWARE;
    return true;
}

tbool FINEXPORT FinaleExtensionEnumerate(const EWND hWnd, const twobyte index,
        FXT_MENUSTRING_PACKET *buf) {
    if (index == 0) {

        strncpy(buf->menuItem, "Unmute region", MAX_MENUSTR_LEN);
        strncpy(buf->msgString, "Marks the note entries to play back.", MAX_MSGSTR_LEN);
        strncpy(buf->undoString, "Unmute", MAX_UNDOSTR_LEN);
        buf->needSelectedRegion = true;
        buf->useGetMenuStatus = false;
        return true;
    }
    else if (index == 1)
    {
        strncpy(buf->menuItem, "Mute region", MAX_MENUSTR_LEN);
        strncpy(buf->msgString, "Marks the note entries to be muted.", MAX_MSGSTR_LEN);
        strncpy(buf->undoString, "Mute", MAX_UNDOSTR_LEN);
        buf->needSelectedRegion = true;
        buf->useGetMenuStatus = false;
        return true;
    }
    return false;
}

tbool FINEXPORT FinaleExtensionInvoke(const EWND hWnd, const twobyte index,
                EREGION* pSelRegion, EREGION * /* pDocRegion */)
{
    FCMusicRegion region(pSelRegion);
    MuteOrUnmuteNotes(&region, (index == 0));
    return false; // No visual document update
}

void FINEXPORT FinaleExtensionTerminate(const EWND /*hWnd*/) {
}

tbool FINEXPORT FinaleExtensionGetMenuStatus(const twobyte /* index */) {
    return true;
}


#if OPERATING_SYSTEM == WINDOWS
int main(int argc, char** argv) {

    return (EXIT_SUCCESS);
}
#endif
